/*
 * file CqReplica.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqReplica
 *
 *  Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stp.StpResource;


/**
 * A proxy interface for a ClearQuest replica. Proxies of this type are returned
 * by the CqDb.LOCAL_REPLICA property and the CQ_MASTER_REPLICA property of
 * CqGroup, CQUser, CqQueryFolderItem, and CqRecord. A database has mastership
 * of a resource if it's LOCAL_REPLICA property matches the CQ_MASTER_REPLICA of
 * the resource. Setting the CQ_MASTER_REPLICA property of a resource to a new
 * CqReplica value will change the mastership of that resource to that replica.
 * A list of possible replica names is returned by the CHOICE_LIST property of
 * the system-owned field named "ratl_mastership"
 * <p>
 * The user-friendly specification for the location of a replica has the form
 * 
 * <pre>
 *  <b>cq.replica:</b><i>&lt;replica-name&gt;</i>@<i>&lt;db-set&gt;</i>
 * </pre>
 */
public interface CqReplica extends CqResource
{
    /** The database set that contains this replica */
    PropertyName<CqDbSet> DB_SET =
        new PropertyName<CqDbSet>(PROPERTY_NAMESPACE, "db-set");

    /**
     * Returns the value of the {@link #DB_SET DB_SET} property as defined by
     * this proxy.
     * 
     * @return A CqDbSet proxy for the database set that contains this replica.
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #DB_SET DB_SET} property.
     */
    CqDbSet getDbSet() throws WvcmException;
}
